@@ -1,23 +1,20 @@
-from logging import log
 import os
-import sys
-from dataherb.cmd.create import describe_dataset
-from dataherb.cmd.configs import load_dataherb_config
 from pathlib import Path
-from datapackage import Package
-from dataherb.cmd.sync_s3 import upload_dataset_to_s3
-from dataherb.cmd.sync_git import upload_dataset_to_git
-from dataherb.serve.save_mkdocs import SaveMkDocs
-
-from mkdocs.commands.serve import serve as _serve
 
 import click
 import git
+from datapackage import Package
 from loguru import logger
+from mkdocs.commands.serve import serve as _serve
 
+from dataherb.cmd.configs import load_dataherb_config
+from dataherb.cmd.create import describe_dataset
+from dataherb.cmd.sync_git import upload_dataset_to_git
+from dataherb.cmd.sync_s3 import upload_dataset_to_s3
+from dataherb.core.base import Herb
 from dataherb.flora import Flora
 from dataherb.parse.model_json import STATUS_CODE, MetaData
-from dataherb.core.base import Herb
+from dataherb.serve.save_mkdocs import SaveMkDocs
 
 __CWD__ = os.getcwd()
 
@@ -77,7 +74,7 @@ def search(flora, id=None, keywords=None):
 @dataherb.command()
 @click.option("--flora", "-f", default=which_flora)
 @click.option("--workdir", "-w", default=WD, required=True)
-@click.option("--dev_addr", "-a", metavar='<IP:PORT>')
+@click.option("--dev_addr", "-a", metavar="<IP:PORT>")
 def serve(flora, workdir, dev_addr):
     fl = Flora(flora=flora)
     mk = SaveMkDocs(flora=fl, workdir=workdir)
@@ -89,9 +86,6 @@ def serve(flora, workdir, dev_addr):
     _serve(config_file=mkdocs_config, dev_addr=dev_addr)
 
 
-
-
-
 @dataherb.command()
 @click.argument("id", required=True)
 @click.option("--flora", "-f", default=which_flora)
@@ -112,11 +106,21 @@ def download(id, flora):
         result_id = result_metadata.get("id")
         dest_folder = str(Path(WD) / result_id)
         if os.path.exists(dest_folder):
-            click.echo(f"Can not download dataset to {dest_folder}: folder exists.")
+            click.echo(f"Can not download dataset to {dest_folder}: folder exists.\n")
+
+            is_pull = click.confirm(f"Would you like to pull from remote?")
+            if is_pull:
+                repo = git.Repo(dest_folder)
+                repo.git.pull()
+            else:
+                click.echo(
+                    f"Please go to the folder {dest_folder} and sync your repo manually."
+                )
         else:
             # dest_folder_parent = f"./{result_repository.split('/')[0]}"
             os.makedirs(dest_folder)
-            git.Git(dest_folder).clone(result_uri)
+            repo = git.repo.base.Repo.clone_from(result_uri, to_path=dest_folder)
+            # git.Git(dest_folder).clone(result_uri)
 
 
 @dataherb.command()
