@@ -1,10 +1,6 @@
-import logging
+from loguru import logger
 from dataherb.parse.model import MetaData
 
-logging.basicConfig()
-logger = logging.getLogger("dataherb.parse.csv")
-
-
 
 if __name__ == "__main__":
-    logger.debug("End of Game")
\ No newline at end of file
+    logger.debug("End of Game")
